Re-exports
pub use channels_guard::ChannelsGuard;pub use channels_guard::ChannelsGuardBuilder;
Modules
Macros
- channel
- Instrument a channel creation to wrap it with debugging proxies. Currently only supports bounded, unbounded and oneshot channels.
- stream
- Instrument a stream to track its item yields.
Structs
- Channel
Logs - Serializable log response containing sent and received logs for channels.
- Channels
Json - Wrapper for channels-only JSON response
- Combined
Json - Combined wrapper for both channels and streams JSON response
- LogEntry
- A single log entry for a message sent or received.
- Serializable
Channel Stats - Serializable version of channel statistics for JSON responses.
- Serializable
Stream Stats - Serializable version of stream statistics for JSON responses.
- Stream
Logs - Serializable log response containing yielded logs for streams.
- Streams
Json - Wrapper for streams-only JSON response
Enums
- Channel
State - State of a instrumented channel.
- Channel
Type - Type of a channel.
- Format
- Format of the output produced by ChannelsGuard on drop.
Functions
- format_
bytes - Format bytes into human-readable units (B, KB, MB, GB, TB).