Crate channels_console
Source - instrument
- Instrument a channel creation to wrap it with debugging proxies.
Currently only supports bounded, unbounded and oneshot channels.
- ChannelsGuard
- Guard for channel statistics collection.
When dropped, prints a summary of all instrumented channels and their statistics.
- ChannelsGuardBuilder
- Builder for creating a ChannelsGuard with custom configuration.
- SerializableChannelStats
- Serializable version of channel statistics for JSON responses.
- ChannelState
- State of a instrumented channel.
- ChannelType
- Type of a channel.
- Format
- Format of the output produced by ChannelsGuard on drop.
- format_bytes
- Format bytes into human-readable units (B, KB, MB, GB, TB).